@@ -36,13 +36,13 @@
 // ----------------------------------------------------------------------------
 // KDE Headers
 
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
 #include <kprogress.h>
 #include <kinputdialog.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 
 // ----------------------------------------------------------------------------
 // Project Headers
@@ -129,7 +129,7 @@ void MyMoneyQifReader::Private::finishStatement(void)
   // in case we have collected any data in the statement, we keep it
   if((st.m_listTransactions.count() + st.m_listPrices.count() + st.m_listSecurities.count()) > 0) {
     statements += st;
-    qDebug("Statement with %d transactions, %d prices and %d securities added to the statement list",
+    tqDebug("Statement with %d transactions, %d prices and %d securities added to the statement list",
            st.m_listTransactions.count(), st.m_listPrices.count(), st.m_listSecurities.count());
   }
   // start with a fresh statement
@@ -250,10 +250,10 @@ MyMoneyQifReader::MyMoneyQifReader() :
   m_warnedSecurity = false;
   m_warnedPrice = false;
 
-  connect(&m_filter, TQT_SIGNAL(wroteStdin(KProcess*)), this, TQT_SLOT(slotSendDataToFilter()));
-  connect(&m_filter, TQT_SIGNAL(receivedStdout(KProcess*, char*, int)), this, TQT_SLOT(slotReceivedDataFromFilter(KProcess*, char*, int)));
-  connect(&m_filter, TQT_SIGNAL(processExited(KProcess*)), this, TQT_SLOT(slotImportFinished()));
-  connect(&m_filter, TQT_SIGNAL(receivedStderr(KProcess*, char*, int)), this, TQT_SLOT(slotReceivedErrorFromFilter(KProcess*, char*, int)));
+  connect(&m_filter, TQT_SIGNAL(wroteStdin(TDEProcess*)), this, TQT_SLOT(slotSendDataToFilter()));
+  connect(&m_filter, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQT_SLOT(slotReceivedDataFromFilter(TDEProcess*, char*, int)));
+  connect(&m_filter, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(slotImportFinished()));
+  connect(&m_filter, TQT_SIGNAL(receivedStderr(TDEProcess*, char*, int)), this, TQT_SLOT(slotReceivedErrorFromFilter(TDEProcess*, char*, int)));
 }
 
 MyMoneyQifReader::~MyMoneyQifReader()
@@ -288,7 +288,7 @@ void MyMoneyQifReader::slotSendDataToFilter(void)
   } else {
     len = m_file->readBlock(m_buffer, sizeof(m_buffer));
     if(len == -1) {
-      qWarning("Failed to read block from QIF import file");
+      tqWarning("Failed to read block from QIF import file");
       m_filter.closeStdin();
       m_filter.kill();
     } else {
@@ -297,14 +297,14 @@ void MyMoneyQifReader::slotSendDataToFilter(void)
   }
 }
 
-void MyMoneyQifReader::slotReceivedErrorFromFilter(KProcess* /* proc */, char *buff, int len)
+void MyMoneyQifReader::slotReceivedErrorFromFilter(TDEProcess* /* proc */, char *buff, int len)
 {
   TQByteArray data;
   data.duplicate(buff, len);
-  qWarning("%s",static_cast<const char*>(data));
+  tqWarning("%s",static_cast<const char*>(data));
 }
 
-void MyMoneyQifReader::slotReceivedDataFromFilter(KProcess* /* proc */, char *buff, int len)
+void MyMoneyQifReader::slotReceivedDataFromFilter(TDEProcess* /* proc */, char *buff, int len)
 {
   m_pos += len;
   // signalProgress(m_pos, 0);
@@ -332,7 +332,7 @@ void MyMoneyQifReader::slotImportFinished(void)
   if(!m_lineBuffer.isEmpty()) {
     m_qifLines << TQString::fromUtf8(m_lineBuffer.stripWhiteSpace());
   }
-  qDebug("Read %d bytes", m_pos);
+  tqDebug("Read %d bytes", m_pos);
   TQTimer::singleShot(0, this, TQT_SLOT(slotProcessData()));
 }
 
@@ -361,13 +361,13 @@ void MyMoneyQifReader::slotProcessData(void)
 
   m_qifProfile.setInputDateFormat(list.first());
 
-  qDebug("Selected date format: '%s'", list.first().data());
+  tqDebug("Selected date format: '%s'", list.first().data());
 
   signalProgress(0, m_qifLines.count(), i18n("Importing QIF ..."));
   TQStringList::iterator it;
   for(it = m_qifLines.begin(); m_userAbort == false && it != m_qifLines.end(); ++it) {
     ++m_linenumber;
-    // qDebug("Proc: '%s'", (*it).data());
+    // tqDebug("Proc: '%s'", (*it).data());
     if((*it).startsWith("!")) {
       processQifSpecial(*it);
       m_qifEntry.clear();
@@ -383,7 +383,7 @@ void MyMoneyQifReader::slotProcessData(void)
   }
   d->finishStatement();
 
-  qDebug("%d lines processed", m_linenumber);
+  tqDebug("%d lines processed", m_linenumber);
   signalProgress(-1, -1);
 
   emit importFinished();
@@ -402,10 +402,10 @@ bool MyMoneyQifReader::startImport(void)
   m_filename = TQString();
   m_data.clear();
 
-  if(!KIO::NetAccess::download(m_url, m_filename, NULL)) {
+  if(!TDEIO::NetAccess::download(m_url, m_filename, NULL)) {
     KMessageBox::detailedError(0,
                                i18n("Error while loading file '%1'!").arg(m_url.prettyURL()),
-                               KIO::NetAccess::lastErrorString(),
+                               TDEIO::NetAccess::lastErrorString(),
                                i18n("File access error"));
     return false;
   }
@@ -419,7 +419,7 @@ bool MyMoneyQifReader::startImport(void)
     while(!m_file->atEnd()) {
       len = m_file->readBlock(m_buffer, sizeof(m_buffer));
       if(len == -1) {
-        qWarning("Failed to read block from QIF import file");
+        tqWarning("Failed to read block from QIF import file");
       } else {
         slotReceivedDataFromFilter(0, m_buffer, len);
       }
@@ -437,13 +437,13 @@ bool MyMoneyQifReader::startImport(void)
     }
     m_entryType = EntryUnknown;
 
-    if(m_filter.start(KProcess::NotifyOnExit, KProcess::All)) {
+    if(m_filter.start(TDEProcess::NotifyOnExit, TDEProcess::All)) {
       m_filter.resume();
       signalProgress(0, m_file->size(), i18n("Reading QIF ..."));
       slotSendDataToFilter();
       rc = true;
     } else {
-      qDebug("starting filter failed :-(");
+      tqDebug("starting filter failed :-(");
     }
 #endif
   }
@@ -459,7 +459,7 @@ bool MyMoneyQifReader::finishImport(void)
   m_file = 0;
 
   // remove the Don't ask again entries
-  KConfig* config = KGlobal::config();
+  TDEConfig* config = TDEGlobal::config();
   config->setGroup(TQString::fromLatin1("Notification Messages"));
   TQStringList::ConstIterator it;
 
@@ -479,7 +479,7 @@ bool MyMoneyQifReader::finishImport(void)
     m_file = 0;
 
     // remove the Don't ask again entries
-    KConfig* config = KGlobal::config();
+    TDEConfig* config = TDEGlobal::config();
     config->setGroup(TQString::fromLatin1("Notification Messages"));
     TQStringList::ConstIterator it;
 
@@ -493,14 +493,14 @@ bool MyMoneyQifReader::finishImport(void)
     signalProgress(-1, -1);
     rc = !m_userAbort && m_filter.normalExit();
   } else {
-    qWarning("MyMoneyQifReader::finishImport() must not be called while the filter\n\tprocess is still running.");
+    tqWarning("MyMoneyQifReader::finishImport() must not be called while the filter\n\tprocess is still running.");
   }
 #endif
 
   // if a temporary file was constructed by NetAccess::download,
   // then it will be removed with the next call. Otherwise, it
   // stays untouched on the local filesystem
-  KIO::NetAccess::removeTempFile(m_filename);
+  TDEIO::NetAccess::removeTempFile(m_filename);
 
 #if 0
   // Add the transaction entries
@@ -617,7 +617,7 @@ void MyMoneyQifReader::processQifSpecial(const TQString& _line)
       m_entryType = EntrySkip;
 
     } else {
-      qWarning("Unknown export header '!Type:%s' in QIF file on line %d: Skipping section.", line.data(), m_linenumber);
+      tqWarning("Unknown export header '!Type:%s' in QIF file on line %d: Skipping section.", line.data(), m_linenumber);
       m_entryType = EntrySkip;
     }
 
@@ -1990,7 +1990,7 @@ TQString MyMoneyQifReader::processAccountEntry(bool resetAccountId)
   TQString tmp;
 
   account.setName(extractLine('N'));
-  // qDebug("Process account '%s'", account.name().data());
+  // tqDebug("Process account '%s'", account.name().data());
 
   account.setDescription(extractLine('D'));
 
@@ -2047,7 +2047,7 @@ TQString MyMoneyQifReader::processAccountEntry(bool resetAccountId)
       parentAccount = file->asset();
       kmymoney2->createAccount(acc, parentAccount, brokerage, MyMoneyMoney());
       parentAccount = acc;
-      qDebug("We still need to create the stock account in MyMoneyQifReader::processAccountEntry()");
+      tqDebug("We still need to create the stock account in MyMoneyQifReader::processAccountEntry()");
     } else {
       // setup parent according the type of the account
       switch(account.accountGroup()) {
@@ -2073,9 +2073,9 @@ TQString MyMoneyQifReader::processAccountEntry(bool resetAccountId)
     }
     kmymoney2->createAccount(account, parentAccount, brokerage, balance);
     acc = account;
-    // qDebug("Account created");
+    // tqDebug("Account created");
   } else {
-    // qDebug("Existing account found");
+    // tqDebug("Existing account found");
   }
 
   if(resetAccountId) {
