@@ -49,17 +49,17 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <kglobal.h>
-#include <kglobalsettings.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdeglobalsettings.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
-#include <khtmlview.h>
-#include <kconfig.h>
+#include <tdehtmlview.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
-#include <klistview.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
+#include <tdelistview.h>
+#include <tdemessagebox.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -88,7 +88,7 @@ using namespace reports;
 
 KReportsView::KReportTab::KReportTab(KTabWidget* parent, const MyMoneyReport& report ):
   TQWidget( parent, "reporttab" ),
-  m_part( new KHTMLPart( this, "reporttabpart" ) ),
+  m_part( new TDEHTMLPart( this, "reporttabpart" ) ),
   m_chartView( new KReportChartView( this, "reportchart" ) ),
   m_control( new kMyMoneyReportControlDecl( this, "reportcontrol" ) ),
   m_layout( new TQVBoxLayout( this, 11, 6, "reporttablayout" ) ),
@@ -112,10 +112,10 @@ KReportsView::KReportTab::KReportTab(KTabWidget* parent, const MyMoneyReport& re
   m_layout->addWidget( m_chartView );
 
   // I like this icon...
-  TQString icon = KGlobal::dirs()->findResource("icon", "default.kde/16x16/mimetypes/spreadsheet.png");
+  TQString icon = TDEGlobal::dirs()->findResource("icon", "default.tde/16x16/mimetypes/spreadsheet.png");
   // but if it's not there, we'll use ye ol' standard icon
   if ( icon == TQString() )
-    icon = KGlobal::dirs()->findResource("icon", "hicolor/16x16/apps/kmymoney2.png");
+    icon = TDEGlobal::dirs()->findResource("icon", "hicolor/16x16/apps/kmymoney2.png");
 
   parent->insertTab( this, TQIconSet(TQPixmap(icon)), report.name() );
   parent->setTabEnabled( this, true );
@@ -156,7 +156,7 @@ void KReportsView::KReportTab::saveAs( const TQString& filename, bool includeCSS
     else {
       TQTextStream stream(&file);
       
-      TQRegExp exp(TQString("(.*)(<link.*css\" href=)\"(.*)\">(<meta.*%1\" />)(.*)").arg(KGlobal::locale()->encoding()));
+      TQRegExp exp(TQString("(.*)(<link.*css\" href=)\"(.*)\">(<meta.*%1\" />)(.*)").arg(TDEGlobal::locale()->encoding()));
       TQString table = createTable();
       if(exp.search(table) != -1 && includeCSS) {
         TQFile cssFile(exp.cap(3));
@@ -234,13 +234,13 @@ TQString KReportsView::KReportTab::createTable(const TQString& links)
 {
   TQString filename;
   if(!MyMoneyFile::instance()->value("reportstylesheet").isEmpty())
-    filename = KGlobal::dirs()->findResource("appdata", TQString("html/%1").arg(MyMoneyFile::instance()->value("reportstylesheet")));
+    filename = TDEGlobal::dirs()->findResource("appdata", TQString("html/%1").arg(MyMoneyFile::instance()->value("reportstylesheet")));
   if(filename.isEmpty())
-    filename = KGlobal::dirs()->findResource("appdata", "html/kmymoney2.css");
+    filename = TDEGlobal::dirs()->findResource("appdata", "html/kmymoney2.css");
   TQString header = TQString("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\">\n") +
     TQString("<html><head><link rel=\"stylesheet\" type=\"text/css\" href=\"%1\">").arg(filename);
 
-  header += TQString("<meta http-equiv=\"Content-Type\" content=\"text/html; charset=%1\" />").arg(KGlobal::locale()->encoding());
+  header += TQString("<meta http-equiv=\"Content-Type\" content=\"text/html; charset=%1\" />").arg(TDEGlobal::locale()->encoding());
   header += KMyMoneyUtils::variableCSS();
 
   header += "</head><body>\n";
@@ -322,7 +322,7 @@ KReportsView::KReportsView(TQWidget *parent, const char *name ) :
 
   m_listTab = (new TQWidget( m_reportTabWidget, "indextab" ));
   m_listTabLayout = ( new TQVBoxLayout( m_listTab, 11, 6, "indextabLayout") );
-  m_reportListView = new KListView( m_listTab, "m_reportListView" );
+  m_reportListView = new TDEListView( m_listTab, "m_reportListView" );
   m_listTabLayout->addWidget( m_reportListView );
   m_reportTabWidget->insertTab( m_listTab, i18n("Reports") );
 
@@ -339,8 +339,8 @@ KReportsView::KReportsView(TQWidget *parent, const char *name ) :
     this, TQT_SLOT(slotOpenReport(TQListViewItem*)));
   connect(m_reportListView, TQT_SIGNAL(returnPressed(TQListViewItem*)),
     this, TQT_SLOT(slotOpenReport(TQListViewItem*)));
-  connect( m_reportListView, TQT_SIGNAL(contextMenu(KListView*,TQListViewItem*,const TQPoint &)),
-    this, TQT_SLOT(slotListContextMenu(KListView*,TQListViewItem*,const TQPoint &)));
+  connect( m_reportListView, TQT_SIGNAL(contextMenu(TDEListView*,TQListViewItem*,const TQPoint &)),
+    this, TQT_SLOT(slotListContextMenu(TDEListView*,TQListViewItem*,const TQPoint &)));
 
   connect(MyMoneyFile::instance(), TQT_SIGNAL(dataChanged()), this, TQT_SLOT(slotLoadView()));
 }
@@ -381,11 +381,11 @@ TQString KReportsView::KReportGroupListItem::key ( int column, bool ascending )
   if (column == 0)
     return TQString::number(m_nr).rightJustify(3,'0');
   else
-    return KListViewItem::key(column,ascending);
+    return TDEListViewItem::key(column,ascending);
 }
 
-KReportsView::KReportGroupListItem::KReportGroupListItem(KListView* parent, const int nr, TQString name) :
-  KListViewItem(parent),
+KReportsView::KReportGroupListItem::KReportGroupListItem(TDEListView* parent, const int nr, TQString name) :
+  TDEListViewItem(parent),
   m_name(name)
 {
   setNr(nr);
@@ -551,10 +551,10 @@ void KReportsView::slotOpenURL(const KURL &url, const KParts::URLArgs& /* args *
     else if ( command == "delete" )
       slotDelete();
     else
-      qDebug("Unknown command '%s' in KReportsView::slotOpenURL()", static_cast<const char*>(command));
+      tqDebug("Unknown command '%s' in KReportsView::slotOpenURL()", static_cast<const char*>(command));
 
   } else {
-    qDebug("Unknown view '%s' in KReportsView::slotOpenURL()", view.latin1());
+    tqDebug("Unknown view '%s' in KReportsView::slotOpenURL()", view.latin1());
   }
 }
 
@@ -673,7 +673,7 @@ void KReportsView::slotDuplicate(void)
         new KReportListItem( m_reportListView, dupe );
         addReportTab(dupe);
       } catch(MyMoneyException* e) {
-        qDebug("Cannot add report");
+        tqDebug("Cannot add report");
         delete e;
       }
     }
@@ -875,7 +875,7 @@ void KReportsView::addReportTab(const MyMoneyReport& report)
 
 }
 
-void KReportsView::slotListContextMenu(KListView* lv,TQListViewItem* item,const TQPoint & p)
+void KReportsView::slotListContextMenu(TDEListView* lv,TQListViewItem* item,const TQPoint & p)
 {
   if ( lv == m_reportListView && item )
   {
